@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "asciidoc-mode" "0.1.0"
+(define-package "asciidoc-mode" "20260222.1804"
   "Major mode for AsciiDoc markup."
   '((emacs "30.1"))
   :url "https://github.com/bbatsov/asciidoc-mode"
